@@ -1,10 +1,13 @@
 TIME = "/time"
 CREATE_API_KEY = "/create-api-key"
 GET_API_KEYS = "/get-api-keys"
+DELETE_API_KEY = "/delete-api-key"
 TRADE_HISTORY = "/trade-history"
+GET_ORDER_BOOK = "/book"
 GET_ORDER = "/order/"
 OPEN_ORDERS = "/open-orders"
 POST_ORDER = "/order"
 CANCEL = "/order"
 CANCEL_ALL = "/cancel-all"
 MID_POINT="/midpoint"
+PRICE = "/price"
\ No newline at end of file
